@@ -87,11 +87,12 @@ types: dict[str, str] = {
     "AWS::ApplicationSignals::Discovery": "2bbcdf020ea7fc15",
     "AWS::ApplicationSignals::GroupingConfiguration": "d6ba1088512bf212",
     "AWS::ApplicationSignals::ServiceLevelObjective": "148bbf048d668735",
+    "AWS::Athena::CapacityReservation": "cf670cf0253b02eb",
     "AWS::Athena::DataCatalog": "72b7e9ce721875ee",
     "AWS::Athena::NamedQuery": "1fd9b221f87bab5d",
     "AWS::Athena::PreparedStatement": "efe18f0108881514",
     "AWS::Athena::WorkGroup": "98125aa523006e5f",
-    "AWS::AutoScaling::AutoScalingGroup": "9b493a8b2db7d024",
+    "AWS::AutoScaling::AutoScalingGroup": "0ad094ba2f4d25b7",
     "AWS::AutoScaling::LaunchConfiguration": "138fee0bb5542e69",
     "AWS::AutoScaling::LifecycleHook": "0ee139c35778edce",
     "AWS::AutoScaling::ScalingPolicy": "68daf421ab1876df",
@@ -165,9 +166,10 @@ types: dict[str, str] = {
     "AWS::CloudTrail::ResourcePolicy": "ab2ae9ccbbd62450",
     "AWS::CloudTrail::Trail": "7afdcfb6fa95406a",
     "AWS::CloudWatch::Alarm": "0602d31ab163094b",
+    "AWS::CloudWatch::AlarmMuteRule": "f0a042f925c1171c",
     "AWS::CloudWatch::AnomalyDetector": "13b8b743191bf50f",
     "AWS::CloudWatch::CompositeAlarm": "2b2200aed34aabc4",
-    "AWS::CloudWatch::Dashboard": "2ad9e8712df37703",
+    "AWS::CloudWatch::Dashboard": "423086b5b02bd126",
     "AWS::CloudWatch::InsightRule": "7b287284e7e98391",
     "AWS::CloudWatch::MetricStream": "ab20b9e49eb444d9",
     "AWS::CodeBuild::Project": "1da142422f2ef55c",
@@ -175,7 +177,7 @@ types: dict[str, str] = {
     "AWS::CodeBuild::SourceCredential": "b84e190d9ebbbfe1",
     "AWS::CodeDeploy::Application": "eea8100bd279b205",
     "AWS::CodeDeploy::DeploymentConfig": "394f39ae21382747",
-    "AWS::CodeDeploy::DeploymentGroup": "77584bdaaa186620",
+    "AWS::CodeDeploy::DeploymentGroup": "a5b18163cfa68275",
     "AWS::CodePipeline::CustomActionType": "b1ae4c1b735eeb9f",
     "AWS::CodePipeline::Pipeline": "ecdbe888f27625fb",
     "AWS::CodePipeline::Webhook": "a6ad2a4dc85ed032",
@@ -185,7 +187,7 @@ types: dict[str, str] = {
     "AWS::Cognito::LogDeliveryConfiguration": "2e1fa665bc591a0b",
     "AWS::Cognito::ManagedLoginBranding": "5c891e6d32f0ba8d",
     "AWS::Cognito::Terms": "f5bf1f3a97d979ba",
-    "AWS::Cognito::UserPool": "d41f3a76d4e01b78",
+    "AWS::Cognito::UserPool": "615b9da8e393791f",
     "AWS::Cognito::UserPoolClient": "fe665a1921d29144",
     "AWS::Cognito::UserPoolDomain": "b89172fa4b1cf22a",
     "AWS::Cognito::UserPoolGroup": "a7315a389c858da9",
@@ -231,34 +233,35 @@ types: dict[str, str] = {
     "AWS::DirectoryService::SimpleAD": "a87f6c61453bc19b",
     "AWS::DynamoDB::GlobalTable": "dcad01d68f1b0691",
     "AWS::DynamoDB::Table": "50e57ed2b28d4230",
-    "AWS::EC2::CapacityReservation": "d8685a879c65fa62",
-    "AWS::EC2::CapacityReservationFleet": "1e2f4d93eb1eca8c",
+    "AWS::EC2::CapacityReservation": "1ab29c6314095182",
+    "AWS::EC2::CapacityReservationFleet": "5d448b59c2d73e04",
     "AWS::EC2::ClientVpnAuthorizationRule": "09dec539b3c3f428",
     "AWS::EC2::ClientVpnEndpoint": "d132f32844d7e05e",
     "AWS::EC2::ClientVpnRoute": "f1d130776f4e1473",
     "AWS::EC2::ClientVpnTargetNetworkAssociation": "d69233d655faf0f6",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "f77f984240fc75d6",
+    "AWS::EC2::EC2Fleet": "1a8415e48effd9a9",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
     "AWS::EC2::FlowLog": "ea553ae6f4a71ce3",
     "AWS::EC2::GatewayRouteTableAssociation": "50b450990964d2e7",
-    "AWS::EC2::Host": "09160fa1050b6c6f",
+    "AWS::EC2::Host": "078ff42d61bf90e9",
     "AWS::EC2::IPAM": "3bab32d28a4ef063",
     "AWS::EC2::IPAMAllocation": "c4cba824ca02ce4f",
     "AWS::EC2::IPAMPool": "f8632a39914b3366",
     "AWS::EC2::IPAMPoolCidr": "873e7cc6e6afef96",
+    "AWS::EC2::IPAMPrefixListResolver": "475d81b7a683c9d6",
     "AWS::EC2::IPAMResourceDiscovery": "0a21294934d111b5",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
     "AWS::EC2::IPAMScope": "f1341090e0e57749",
-    "AWS::EC2::Instance": "c1924dda15cc3d7b",
+    "AWS::EC2::Instance": "7a8c89a99087d7d5",
     "AWS::EC2::InstanceConnectEndpoint": "ccb7d5f817cc9d24",
     "AWS::EC2::InternetGateway": "4c7c90cb3105c9d8",
     "AWS::EC2::IpPoolRouteTableAssociation": "071b5a1f00936f72",
     "AWS::EC2::KeyPair": "349deb28f79434e4",
-    "AWS::EC2::LaunchTemplate": "0cb1d6824b527dcd",
+    "AWS::EC2::LaunchTemplate": "dc7d758834e70fcb",
     "AWS::EC2::LocalGatewayRoute": "b50d8737e0b1ea90",
     "AWS::EC2::LocalGatewayRouteTable": "6892bdd3f1f99df6",
     "AWS::EC2::LocalGatewayRouteTableVPCAssociation": "b1d6ce946dcb69b8",
@@ -301,17 +304,17 @@ types: dict[str, str] = {
     "AWS::EC2::TrafficMirrorTarget": "562f502a60abccd6",
     "AWS::EC2::TransitGateway": "bdd0278ecaccd4ae",
     "AWS::EC2::TransitGatewayAttachment": "40111e00bf0df74a",
-    "AWS::EC2::TransitGatewayConnect": "05caf42b9c40a843",
+    "AWS::EC2::TransitGatewayConnect": "f3001456d8e71829",
     "AWS::EC2::TransitGatewayConnectPeer": "27459a628d254042",
     "AWS::EC2::TransitGatewayMeteringPolicy": "4daf1939996f77df",
     "AWS::EC2::TransitGatewayMeteringPolicyEntry": "153b7c0d6fcca798",
-    "AWS::EC2::TransitGatewayMulticastDomain": "8a9fdc16690320b7",
+    "AWS::EC2::TransitGatewayMulticastDomain": "55ac3f0e32f72ab4",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation": "f650430e0bbdcce9",
     "AWS::EC2::TransitGatewayMulticastGroupMember": "fe8c827e156dc451",
     "AWS::EC2::TransitGatewayMulticastGroupSource": "95b20156fbc77eb0",
     "AWS::EC2::TransitGatewayPeeringAttachment": "2a33a8efb207e5e5",
     "AWS::EC2::TransitGatewayRoute": "41a8efed021fd377",
-    "AWS::EC2::TransitGatewayRouteTable": "46974e4ed5fe86b7",
+    "AWS::EC2::TransitGatewayRouteTable": "cb8a1d0ac988c165",
     "AWS::EC2::TransitGatewayRouteTableAssociation": "a28bde73d4a5cde6",
     "AWS::EC2::TransitGatewayRouteTablePropagation": "e21e0c3273d49afe",
     "AWS::EC2::TransitGatewayVpcAttachment": "9f86e47a59b89462",
@@ -326,9 +329,9 @@ types: dict[str, str] = {
     "AWS::EC2::VPCEndpointService": "150eafe6174fc552",
     "AWS::EC2::VPCEndpointServicePermissions": "5841ea22a0cbb143",
     "AWS::EC2::VPCGatewayAttachment": "1dc77043848e8e94",
-    "AWS::EC2::VPCPeeringConnection": "e01a466d269170ed",
+    "AWS::EC2::VPCPeeringConnection": "41b9860245304058",
     "AWS::EC2::VPNConcentrator": "78aca3962b6da301",
-    "AWS::EC2::VPNConnection": "3bf3a2c97e027241",
+    "AWS::EC2::VPNConnection": "64de71e4f82fffe6",
     "AWS::EC2::VPNConnectionRoute": "00194e67a2d7f53d",
     "AWS::EC2::VPNGateway": "1e2f029e99547e1a",
     "AWS::EC2::VPNGatewayRoutePropagation": "5e03d41fa9dc15b9",
@@ -357,13 +360,13 @@ types: dict[str, str] = {
     "AWS::EFS::FileSystem": "575ef4f21bc6f9da",
     "AWS::EFS::MountTarget": "562530cf9ce264a6",
     "AWS::EKS::AccessEntry": "6eb6ba186799e7f3",
-    "AWS::EKS::Addon": "f27379fa02ce1e45",
+    "AWS::EKS::Addon": "63cae0a921c6a93d",
     "AWS::EKS::Capability": "7816d4a96b146b20",
     "AWS::EKS::Cluster": "46cd8dea9cf6c5d7",
     "AWS::EKS::FargateProfile": "54a9efe57f089a05",
     "AWS::EKS::IdentityProviderConfig": "77b807192827540b",
-    "AWS::EKS::Nodegroup": "4b7b3ba6fffc3e8a",
-    "AWS::EKS::PodIdentityAssociation": "d4249aaeb9409683",
+    "AWS::EKS::Nodegroup": "11f90e70c2b0b5a1",
+    "AWS::EKS::PodIdentityAssociation": "c9fa86f74de95001",
     "AWS::EMR::Cluster": "ac0466c8197ef416",
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
     "AWS::EMR::InstanceGroupConfig": "57ea4fa9b7b6f658",
@@ -376,7 +379,7 @@ types: dict[str, str] = {
     "AWS::ElastiCache::CacheCluster": "1220b6bbd633ae68",
     "AWS::ElastiCache::GlobalReplicationGroup": "2af3062bf5b2cf7f",
     "AWS::ElastiCache::ParameterGroup": "b0e1dec3cd05f739",
-    "AWS::ElastiCache::ReplicationGroup": "59defd83ba1cb2f2",
+    "AWS::ElastiCache::ReplicationGroup": "0b94d00dcdccdba6",
     "AWS::ElastiCache::SecurityGroup": "075dfa59da275723",
     "AWS::ElastiCache::SecurityGroupIngress": "96d1b4a5bd438d25",
     "AWS::ElastiCache::ServerlessCache": "67ad14ea2425e853",
@@ -393,7 +396,7 @@ types: dict[str, str] = {
     "AWS::ElasticLoadBalancingV2::ListenerRule": "1887769bb7b98082",
     "AWS::ElasticLoadBalancingV2::LoadBalancer": "f94791113edc7b8a",
     "AWS::ElasticLoadBalancingV2::TargetGroup": "0eedcff0831b4a32",
-    "AWS::ElasticLoadBalancingV2::TrustStore": "5c70c395153b88f1",
+    "AWS::ElasticLoadBalancingV2::TrustStore": "91b22a729d45fd13",
     "AWS::ElasticLoadBalancingV2::TrustStoreRevocation": "593a78e5ca9c2be3",
     "AWS::Elasticsearch::Domain": "c6414ef13f2fedbe",
     "AWS::EventSchemas::Discoverer": "26c475458e43d0a3",
@@ -407,7 +410,7 @@ types: dict[str, str] = {
     "AWS::Events::EventBusPolicy": "7cb0a2b18483bb52",
     "AWS::Events::Rule": "65aec73d3b811c08",
     "AWS::FMS::NotificationChannel": "3dfde465b38d83be",
-    "AWS::FMS::Policy": "3d3868b1e974d27b",
+    "AWS::FMS::Policy": "9a5d16a686ed3b5d",
     "AWS::FMS::ResourceSet": "6fb04db2dcf50bf8",
     "AWS::FSx::DataRepositoryAssociation": "ecfa3f43f4917224",
     "AWS::FSx::FileSystem": "9741d33840560c55",
@@ -440,14 +443,14 @@ types: dict[str, str] = {
     "AWS::Glue::Trigger": "d61fdd6249ab4ce9",
     "AWS::Glue::Workflow": "7889f86fa2b1958f",
     "AWS::GuardDuty::Detector": "609c5ab9768f30a4",
-    "AWS::GuardDuty::Filter": "f38bf8e909cfd2c8",
+    "AWS::GuardDuty::Filter": "5effc026fb87131d",
     "AWS::GuardDuty::IPSet": "82e2140b58b00302",
     "AWS::GuardDuty::MalwareProtectionPlan": "d875ebc427de851e",
     "AWS::GuardDuty::Master": "5115377f51b894ca",
     "AWS::GuardDuty::Member": "4410bf4350c9fdb8",
     "AWS::GuardDuty::PublishingDestination": "95c6a8d647a77c52",
     "AWS::GuardDuty::ThreatEntitySet": "f9e73b098cba1e1d",
-    "AWS::GuardDuty::ThreatIntelSet": "09915bee5770f4c9",
+    "AWS::GuardDuty::ThreatIntelSet": "41eb1d839da4d715",
     "AWS::GuardDuty::TrustedEntitySet": "150ef5b439192da2",
     "AWS::IAM::AccessKey": "62d91b17309e76c8",
     "AWS::IAM::Group": "23f995735d09bdb9",
@@ -473,7 +476,7 @@ types: dict[str, str] = {
     "AWS::ImageBuilder::ImagePipeline": "b439c448d65a8542",
     "AWS::ImageBuilder::ImageRecipe": "37e69d9a511bb367",
     "AWS::ImageBuilder::InfrastructureConfiguration": "703bdd9fb961cbcd",
-    "AWS::ImageBuilder::LifecyclePolicy": "8cd39fa4bf49cfef",
+    "AWS::ImageBuilder::LifecyclePolicy": "05e1176be456713a",
     "AWS::ImageBuilder::Workflow": "13db705a33e231c9",
     "AWS::InspectorV2::CisScanConfiguration": "6a0dfa78d5d181cb",
     "AWS::InspectorV2::Filter": "075d0c9233498945",
@@ -493,7 +496,7 @@ types: dict[str, str] = {
     "AWS::KMS::Alias": "28f10f922a4d194f",
     "AWS::KMS::Key": "c70e396ee12ddb65",
     "AWS::KMS::ReplicaKey": "903f43e74c8d8853",
-    "AWS::KafkaConnect::Connector": "370eb0711a58ca24",
+    "AWS::KafkaConnect::Connector": "02c89e2c1eb3d4f3",
     "AWS::KafkaConnect::CustomPlugin": "b57a0879af8759b3",
     "AWS::KafkaConnect::WorkerConfiguration": "1f80a6b9f1a4d5be",
     "AWS::Kinesis::ResourcePolicy": "39996915810e234a",
@@ -543,12 +546,13 @@ types: dict[str, str] = {
     "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
     "AWS::Logs::ResourcePolicy": "d7898253a7730ac3",
     "AWS::Logs::SubscriptionFilter": "c1ec900772212dcf",
-    "AWS::Logs::Transformer": "66b4b09c596d83c0",
+    "AWS::Logs::Transformer": "943d9e7f35c1fc2c",
     "AWS::MSK::BatchScramSecret": "ff2b807a577495b0",
-    "AWS::MSK::Cluster": "07d7025a3ae5e3bb",
+    "AWS::MSK::Cluster": "d2642928d6736e1c",
     "AWS::MSK::ClusterPolicy": "b60740da22ea8c04",
     "AWS::MSK::Configuration": "61dbb22c2b6cbbb1",
     "AWS::MSK::Replicator": "e4c147fed22ae544",
+    "AWS::MSK::Topic": "7c3b1270fbb7dbf8",
     "AWS::MSK::VpcConnection": "6aeb07916b90c80a",
     "AWS::MWAA::Environment": "c28ab3624f1d638c",
     "AWS::Neptune::DBCluster": "8d9215c18d4689e5",
@@ -688,7 +692,7 @@ types: dict[str, str] = {
     "AWS::S3Outposts::BucketPolicy": "29126ab2fb9793f6",
     "AWS::S3Outposts::Endpoint": "323c92664ebd7f95",
     "AWS::S3Tables::Namespace": "148f9286df26a384",
-    "AWS::S3Tables::Table": "a3eed252e01d4a85",
+    "AWS::S3Tables::Table": "06c0bb9325f0bc8c",
     "AWS::S3Tables::TableBucket": "c87800af01ff17ff",
     "AWS::S3Tables::TableBucketPolicy": "8a4df56718b22c4c",
     "AWS::S3Tables::TablePolicy": "a400a63607882bc8",
@@ -696,6 +700,7 @@ types: dict[str, str] = {
     "AWS::SES::ConfigurationSet": "5d4781bc5cccba7b",
     "AWS::SES::ConfigurationSetEventDestination": "f4e74b1d7e859c34",
     "AWS::SES::ContactList": "c5a40d0f3d530e19",
+    "AWS::SES::CustomVerificationEmailTemplate": "4f52e41f83844ece",
     "AWS::SES::DedicatedIpPool": "1485a5989d771f62",
     "AWS::SES::EmailIdentity": "be6211158f395729",
     "AWS::SES::MailManagerAddonInstance": "2012772f13a846eb",
@@ -710,7 +715,7 @@ types: dict[str, str] = {
     "AWS::SES::ReceiptFilter": "f16f5cdaa2594ab2",
     "AWS::SES::ReceiptRule": "0f5b074f6f6bb4cc",
     "AWS::SES::ReceiptRuleSet": "79ecdd974ccaeb6a",
-    "AWS::SES::Template": "20af669206370beb",
+    "AWS::SES::Template": "b50788c843c91468",
     "AWS::SES::Tenant": "0c003f20faaf4446",
     "AWS::SES::VdmAttributes": "15df0379061c0489",
     "AWS::SMSVOICE::ConfigurationSet": "2bdda88e956e2a26",
@@ -743,7 +748,7 @@ types: dict[str, str] = {
     "AWS::SSO::PermissionSet": "e4212a96dd4b627d",
     "AWS::SageMaker::App": "48a84d4277803da3",
     "AWS::SageMaker::AppImageConfig": "0500a25b2fd80213",
-    "AWS::SageMaker::Cluster": "c21b132cc766ec37",
+    "AWS::SageMaker::Cluster": "439ccbf60a68017e",
     "AWS::SageMaker::CodeRepository": "d59f5cf4521ff1c2",
     "AWS::SageMaker::Domain": "c2a82bf359890cfa",
     "AWS::SageMaker::Endpoint": "bcd29d1fafd461ae",
@@ -755,7 +760,7 @@ types: dict[str, str] = {
     "AWS::SageMaker::MlflowTrackingServer": "82716f2317f73364",
     "AWS::SageMaker::Model": "9757bf2bdc6a25ef",
     "AWS::SageMaker::ModelCard": "89534938581c1015",
-    "AWS::SageMaker::ModelPackage": "31c3d161301c2d13",
+    "AWS::SageMaker::ModelPackage": "20d340cd288752de",
     "AWS::SageMaker::ModelPackageGroup": "69804fe68f09f66e",
     "AWS::SageMaker::NotebookInstance": "f222a6268560b3b6",
     "AWS::SageMaker::Pipeline": "d0698ac81fb18f57",
@@ -763,7 +768,7 @@ types: dict[str, str] = {
     "AWS::SageMaker::Project": "a659dd2080a26111",
     "AWS::SageMaker::Space": "e5a34d8a4bf33a34",
     "AWS::SageMaker::StudioLifecycleConfig": "5654680d7015fbd4",
-    "AWS::SageMaker::UserProfile": "0b1d6e7b47d96c39",
+    "AWS::SageMaker::UserProfile": "85348681edf23c87",
     "AWS::SageMaker::Workteam": "d617e40122a8fe93",
     "AWS::Scheduler::Schedule": "e8b60514af25a837",
     "AWS::Scheduler::ScheduleGroup": "ef710d09dbb243bf",
@@ -817,10 +822,11 @@ types: dict[str, str] = {
     "AWS::StepFunctions::StateMachineVersion": "4467293a52255b78",
     "AWS::Synthetics::Canary": "a553d010d467c6ed",
     "AWS::SystemsManagerSAP::Application": "8196ab023743f75e",
-    "AWS::Timestream::InfluxDBInstance": "a7fa0ea06ccd1174",
+    "AWS::Timestream::InfluxDBCluster": "5ffa44bb275acc7b",
+    "AWS::Timestream::InfluxDBInstance": "e124cda52f244d12",
     "AWS::Transfer::Agreement": "1013512feba974f8",
     "AWS::Transfer::Certificate": "f7478973edec7bd3",
-    "AWS::Transfer::Connector": "7955ea7e4c5f3e22",
+    "AWS::Transfer::Connector": "8827021611524252",
     "AWS::Transfer::Profile": "88c7478695f7c070",
     "AWS::Transfer::Server": "90b633961fce2a5f",
     "AWS::Transfer::User": "7dbec614b03c1346",
@@ -828,7 +834,7 @@ types: dict[str, str] = {
     "AWS::Transfer::Workflow": "851674d5732910da",
     "AWS::VerifiedPermissions::IdentitySource": "b6f4f19263afee23",
     "AWS::VerifiedPermissions::Policy": "f7e75c34791cf6a5",
-    "AWS::VerifiedPermissions::PolicyStore": "5883732ea6547044",
+    "AWS::VerifiedPermissions::PolicyStore": "d797894a95fb9d61",
     "AWS::VerifiedPermissions::PolicyTemplate": "067128efc0e8f2eb",
     "AWS::VpcLattice::AccessLogSubscription": "fc931efc318e179a",
     "AWS::VpcLattice::AuthPolicy": "4265f5022282b0dc",
@@ -854,7 +860,7 @@ types: dict[str, str] = {
     "AWS::WAFv2::RuleGroup": "17c881f134c11dbb",
     "AWS::WAFv2::WebACL": "27eb9031e644a7fd",
     "AWS::WAFv2::WebACLAssociation": "f47dba384d872bb3",
-    "AWS::WorkSpaces::Workspace": "47517765f7ec71d2",
+    "AWS::WorkSpaces::Workspace": "95eec1aff41966b4",
     "AWS::XRay::Group": "9e6b73a50d7628e1",
     "AWS::XRay::ResourcePolicy": "1eefd10339461fe6",
     "AWS::XRay::SamplingRule": "78c8dff3096127b9",
